@@ -26,8 +26,10 @@
 # OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
+__all__ = ("YOUTUBE_API_BASE_URL", "YOUTUBE_API_SCOPES", "YouTubeBot", "ux")
+
 __productname__ = "chatto"
-__version__ = "0.0.0"
+__version__ = "0.1.1"
 __description__ = "A unified API wrapper for YouTube and Twitch chat bots."
 __url__ = "https://github.com/parafoxia/chatto"
 __docs__ = "https://chatto.readthedocs.io/en/latest"
@@ -36,3 +38,9 @@ __author_email__ = "ethan.henderson.1998@gmail.com"
 __license__ = "BSD 3-Clause 'New' or 'Revised' License"
 __bugtracker__ = "https://github.com/parafoxia/chatto/issues"
 __ci__ = "https://github.com/parafoxia/chatto/actions"
+
+from . import ux
+from .youtube import YouTubeBot
+
+YOUTUBE_API_BASE_URL = "https://www.googleapis.com/youtube/v3"
+YOUTUBE_API_SCOPES = ("https://www.googleapis.com/auth/youtube",)
